package session

import (
	"context"
	"testing"

	"github.com/jmoiron/sqlx"
	_ "modernc.org/ql/driver"
)

func assertNoError(t *testing.T, err error) {
	if err != nil {
		t.Fatal("unexpected error:", err)
	}
}

func initDB(ctx context.Context, t *testing.T, db *sqlx.DB) {
	tx, err := db.Begin()
	assertNoError(t, err)

	_, err = tx.ExecContext(ctx, `CREATE TABLE state (key string, val string)`)
	assertNoError(t, err)

	_, err = tx.ExecContext(ctx, `INSERT INTO state (key, val) VALUES (?1, ?2)`, "pwsalt", "1234")
	assertNoError(t, err)

	err = tx.Commit()
	assertNoError(t, err)
}

func TestHashPassword(t *testing.T) {
	ctx := context.Background()

	db, err := sqlx.Open("ql-mem", "unit-test")
	assertNoError(t, err)
	defer db.Close()

	initDB(ctx, t, db)

	h1, err := hashPassword(ctx, db, "test-user", "a nice password")
	assertNoError(t, err)

	h2, err := hashPassword(ctx, db, "another-user", "a nice password")
	assertNoError(t, err)

	if h1 == h2 {
		t.Error("did not expect equal hashes")
	}
}

func TestAuthProvider(t *testing.T) {
	t.Skip("not yet")
}
